@@ -1,12 +1,13 @@
-import json
 import multiprocessing as mp
 from pathlib import Path
 from typing import Any, Dict, Iterator, List, Optional, Tuple
 
 import numpy as np
+import orjson as json
+from PIL import Image as PILImage
+
 from darwin.dataset.utils import get_classes, get_release_path, load_pil_image
 from darwin.utils import SUPPORTED_IMAGE_EXTENSIONS, parse_darwin_json
-from PIL import Image as PILImage
 
 
 class LocalDataset(object):
@@ -138,7 +139,7 @@ class LocalDataset(object):
             raise ValueError("There are no annotations downloaded.")
 
         with self.annotations_path[index].open() as f:
-            data = json.load(f)["image"]
+            data = json.loads(f.read())["image"]
             return data
 
     def get_height_and_width(self, index: int) -> Tuple[float, float]:
